@@ -3,7 +3,7 @@ package WWW::FieldValidator;
 use strict;
 use warnings;
 
-our $VERSION = "1.06";
+our $VERSION = "1.19";
 
 # The following constants represent the validator types that can be used to
 # validate the specified user input.
@@ -144,9 +144,17 @@ sub _validateRegex {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::FieldValidator - Provides simple validation of user entered input
+WWW::FieldValidator
+
+=head1 VERSION
+
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -160,6 +168,10 @@ object.  In this case, the only thing you need to know how to do is to
 instantiate WWW::FieldValidators properly.  All the validation is handled
 internally by WWW::Form.
 
+=head1 NAME
+
+WWW::FieldValidator - Provides simple validation of user entered input
+
 =head1 USAGE
 
 =head2 my $validator = WWW::FieldValidator->new($validatorType,$errorFeedback, [$minLength, $maxLength, $regex], [$isOptional])
@@ -327,4 +339,15 @@ a user-defined validation type.)
 This program is free software.  You may copy or redistribute it under the same
 terms as Perl itself.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2003 by Benjamin Schmaus.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
